@@ -7,7 +7,7 @@ use warnings;
 use List::Util qw(none);
 use Readonly;
 use Roman;
-use Unicode::UTF8 qw(decode_utf8);
+use Unicode::UTF8 qw(decode_utf8 encode_utf8);
 
 Readonly::Array our @EXPORT_OK => qw(clean_cover clean_date clean_edition_number
 	clean_number_of_pages clean_oclc clean_publication_date clean_publisher_name
@@ -15,7 +15,7 @@ Readonly::Array our @EXPORT_OK => qw(clean_cover clean_date clean_edition_number
 	clean_title);
 Readonly::Array our @COVERS => qw(hardback paperback);
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 our $DEBUG = 0;
 
 sub clean_cover {
@@ -135,9 +135,13 @@ sub clean_edition_number {
 	$ret_edition_number =~ s/\s*aktualiz\.//ms;
 	$re = decode_utf8('aktualizované');
 	$ret_edition_number =~ s/\s*$re//ms;
+	$re = decode_utf8('značně');
+	$ret_edition_number =~ s/\s*$re//ms;
 	$ret_edition_number =~ s/\s*nezm\.//ms;
 	$re = decode_utf8('rozšířené');
 	$ret_edition_number =~ s/\s*$re//ms;
+	$re = decode_utf8('rozmnožené');
+	$ret_edition_number =~ s/\s*$re//ms;
 	$re = decode_utf8('rozš');
 	$ret_edition_number =~ s/\s*$re\.?//ms;
 	$ret_edition_number =~ s/\s*dopl\.//ms;
@@ -211,7 +215,7 @@ sub clean_edition_number {
 
 	if ($ret_edition_number !~ m/^\d+$/ms) {
 		if ($DEBUG) {
-			warn "Edition number '$edition_number' couldn't clean ($ret_edition_number).";
+			warn encode_utf8("Edition number '$edition_number' couldn't clean ($ret_edition_number).");
 		}
 		$ret_edition_number = undef;
 	}
@@ -683,6 +687,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
